;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#x6ee0c2d54f45d62c0b88961876f620df . "./code.cg2js/cg-acache.fasl")
(#x1bfe9b2675083a31ec183b22eea6e47e . "./code.cg2js/cg-base.fasl")
(#xfbfbd6b83674639641d4f7be880b6242 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#xbac76371500826f77e7c1de1ff66ecff . "./code.cg2js/cg-bitmap-pane.fasl")
(#xaa307e3dca07c7f8bf4326447c4da845 . "./code.cg2js/cg-bitmap-stream.fasl")
(#x0aaa2146bb05f1597524c6ec7f3ea39c . "./code.cg2js/cg-button.fasl")
(#x43c4e5110ab0aec8c0fc0715f3d98c17 . "./code.cg2js/cg-calendar.fasl")
(#x3b022abe6c6d265a597334096a642fcc . "./code.cg2js/cg-caret.fasl")
(#xcf2267efff9770791cf5bab2d49f7455 . "./code.cg2js/cg-chart-or-plot.fasl")
(#xc9845b33b5dcd89319ac3b0da6f435aa . "./code.cg2js/cg-chart-widget.fasl")
(#x6536b90132cb1a4498df25916d914f86 . "./code.cg2js/cg-check-box.fasl")
(#xc13abdf032ada25f0810ac0163f4939a . "./code.cg2js/cg-choice-list.fasl")
(#xca3179ca01abdfe1d166a1289494b585 . "./code.cg2js/cg-choose-printer.fasl")
(#xb744d245209ef10ef99b76ee741fdc40 . "./code.cg2js/cg-class-grid.fasl")
(#x0a309bec488e22fa7b4a0cf792dffe1c . "./code.cg2js/cg-class-slot-grid.fasl")
(#x12f91245abfd0cb56dee8b71e09dce56 . "./code.cg2js/cg-class-support.fasl")
(#x17f9dd5c46e0eddb5b6c11a2a8aecfe6 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#x0f4430583d5d428403862639ea2827bf . "./code.cg2js/cg-clipboard-stack.fasl")
(#x4309b10ba6c5e7f47c224eef26be7eb2 . "./code.cg2js/cg-clipboard.fasl")
(#x71c36dbe7fb581b2941ad4f1f91b7610 . "./code.cg2js/cg-color-dialog.fasl")
(#x3882edde5a65506edd5ce00194a35159 . "./code.cg2js/cg-combo-box.fasl")
(#x7655999b827f25422fe3b16617110aca . "./code.cg2js/cg-common-control.fasl")
(#xb885c24d3c26112321e92e3450f8b1c3 . "./code.cg2js/cg-comtab.fasl")
(#x710050281bcddd9d37bdcc05fa814b84 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#x44d33f349beaab1271e9b54476ed758d . "./code.cg2js/cg-curve.fasl")
(#x72bdff9cbf8d315c3628c7fcd5816b4b . "./code.cg2js/cg-dde-utils.fasl")
(#x1e949c0d0a8754a3409a2a008ca43629 . "./code.cg2js/cg-dev.fasl")
(#x77511eb0b08af54eaea5e5d6b12e2ac5 . "./code.cg2js/cg-dialog-item.fasl")
(#xbe8647a06fa894e0bcc498f8b97d6ebf . "./code.cg2js/cg-directory-dialog-os.fasl")
(#xee342c0cd7e84032853c0796b13b89f8 . "./code.cg2js/cg-directory-dialog.fasl")
(#x4a00d8a26bb7670b9c1f3f4bef8ff314 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#xbe11b0c111312baf93bf48606359c769 . "./code.cg2js/cg-drag-and-drop.fasl")
(#x2f445f83be4619534190d60aa0172258 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x2f5ea7969f24612566be26ef5f2bab2e . "./code.cg2js/cg-drawable.fasl")
(#xb76e2b8f7758af876aa03801d3e41e08 . "./code.cg2js/cg-dropping-outline.fasl")
(#x92760334ed60715e308db9ede6300787 . "./code.cg2js/cg-edit-in-place.fasl")
(#x260adf370a2395e08cc943bfbd2ef6c8 . "./code.cg2js/cg-editable-text.fasl")
(#xb4653b786e27ce29910910fc74ffe724 . "./code.cg2js/cg-file-dialog.fasl")
(#xf75953001db033433ebdb05b65609cbc . "./code.cg2js/cg-fill-texture.fasl")
(#xe50af14ba3d48245968dc10aa1262faf . "./code.cg2js/cg-find-string-dialog.fasl")
(#xbd5f398fa8c33472b7404880b4473d5d . "./code.cg2js/cg-font-dialog.fasl")
(#xbbf26b71c7cf1dcd21312b5e079819ca . "./code.cg2js/cg-gesture-emulation.fasl")
(#x6ee4b2bf4e2288a701b8a595dbce9daf . "./code.cg2js/cg-get-pixmap.fasl")
(#x9e5d93ea2416d1c50fe34bc17cc0c80a . "./code.cg2js/cg-get-position.fasl")
(#xbe1cbd506c5a38e73c8f3fe5f8941388 . "./code.cg2js/cg-graphics-context.fasl")
(#xd89106b9527cc349e7f56b08a6291e33 . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#xe9cb02ac88c9bb7c0e2338166aad5aaa . "./code.cg2js/cg-grid-widget.fasl")
(#x04cb91cbde4ced5e16359361416260e3 . "./code.cg2js/cg-group-box.fasl")
(#x96d8c1265bb701a6c7df13ff63560509 . "./code.cg2js/cg-header-control.fasl")
(#xa4c151f5e3a15549ea174251a1716ee3 . "./code.cg2js/cg-hotspot.fasl")
(#x340a3e023012db23be87ebc1eb769553 . "./code.cg2js/cg-html-dialog.fasl")
(#xdbc0bb3103dc7189fc6be7ae0c0d3165 . "./code.cg2js/cg-html-widget.fasl")
(#x898ea2eda60757adc27f9e99f40f76c9 . "./code.cg2js/cg-icon-pixmap.fasl")
(#xdda5ae03a2b3617edcf58c6b6d79b074 . "./code.cg2js/cg-icon.fasl")
(#xc561e9227b1c070dd08cc6f32d143863 . "./code.cg2js/cg-ie.fasl")
(#xcf98ca91475c07ec07add00d8bc79012 . "./code.cg2js/cg-intersect-posbox.fasl")
(#x6fb12b9a8a748ef62a5b9ce3bd4f34d1 . "./code.cg2js/cg-intersect.fasl")
(#xcc70a6a9fdbf59911b1c05b5b00ce97c . "./code.cg2js/cg-item-list.fasl")
(#x144968555c92be6866b11efcb189f940 . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x449fba6584f6368da8bdbc21614f9b55 . "./code.cg2js/cg-lamp.fasl")
(#xf28292e036d28bae8f6903ec0048260a . "./code.cg2js/cg-layout.fasl")
(#xfda352781ceb69f66759c6b3b51357fa . "./code.cg2js/cg-lettered-menu.fasl")
(#x2426a1f0e1c51649cadc0045a679651f . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x0821d4194cffbc0da56a951356e59f87 . "./code.cg2js/cg-lisp-text.fasl")
(#xfe40865ef31c94fb38129b326edd82df . "./code.cg2js/cg-lisp-widget.fasl")
(#x7762dcdf04c01a9b3d02eaf7cd6405d2 . "./code.cg2js/cg-list-view.fasl")
(#xa0f610979f75dfd688ba5321c9a6c9b2 . "./code.cg2js/cg-mci.fasl")
(#xd0839a195d28fca84d9cf6e565b20c7a . "./code.cg2js/cg-menu-tooltip.fasl")
(#xef5dab18251d438901665bf7df8c9269 . "./code.cg2js/cg-menu.fasl")
(#x0d1cc94dd792d02b650f7c863dfcd038 . "./code.cg2js/cg-message-dialog.fasl")
(#xe67374c07fc031b1f07f5f5ac655efd1 . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x813b7767b8485469449db641404b0c06 . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x60763c8db3ee2cbef952a73fd1b5c432 . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#xc82ed4dd11132d0e7371d123842dda8a . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#x04cf1cca49fe2762c288d63a07ca2a22 . "./code.cg2js/cg-multi-picture-button.fasl")
(#xbe3a300e3146344df5223da764c5253d . "./code.cg2js/cg-nodes.fasl")
(#xc56c1b4f66509a1a30b84c9e3b4ac2eb . "./code.cg2js/cg-object-editor-layout.fasl")
(#x8aa1f284ebb92e4a70e73a320518f7b9 . "./code.cg2js/cg-object-editor.fasl")
(#x2e28d3c6e4c688949322a55c47a41c86 . "./code.cg2js/cg-ocx.fasl")
(#xc2295a74828530fdd304265b38a87ef1 . "./code.cg2js/cg-os-widget.fasl")
(#xd1fbd0d752fa2dbe38001b69ae25fb9a . "./code.cg2js/cg-os-window.fasl")
(#x37596c6797e52c4028047e46c28c511e . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x324602bd0f4841ad6348a9f53b041fd9 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x6565e84589d4f35525f314453b4fdad3 . "./code.cg2js/cg-outline.fasl")
(#xc6bf2035a9ff916630427d04ccedb3ab . "./code.cg2js/cg-palette.fasl")
(#x20426fe4a52a8a5139e696abcb0d6bc6 . "./code.cg2js/cg-paren-matching.fasl")
(#x8402c8ae659afe0dff87c11458f0c389 . "./code.cg2js/cg-picture-widget-palette.fasl")
(#xfc3d9c0e838ddc66654b01baf5ee2c24 . "./code.cg2js/cg-picture-widget.fasl")
(#xc77c4aea27e739864f1f1b4aac0d5e56 . "./code.cg2js/cg-pixmap-file-io.fasl")
(#xdc9de92808c6252ed76386d6d31422e3 . "./code.cg2js/cg-pixmap-printing.fasl")
(#x183eaf58647f475155709679eab2055a . "./code.cg2js/cg-pixmap-rotate.fasl")
(#xc1cac88473b3b3185374a7b16a94df10 . "./code.cg2js/cg-pixmap-widget.fasl")
(#xe62253b586107a1acb26452b3ce393ca . "./code.cg2js/cg-pixmap.fasl")
(#x9406eaa8a17023aedc34569461a9b241 . "./code.cg2js/cg-player.fasl")
(#x832e09da3af69bd31dcb10d2b88796d3 . "./code.cg2js/cg-plot-widget.fasl")
(#x2a7edf2e37e5a81ba302b07fae9b6a51 . "./code.cg2js/cg-printing.fasl")
(#x4043017ea099f9de0a72052578ce0103 . "./code.cg2js/cg-progress-indicator.fasl")
(#x651a2c57c3a12d7bccac37321ff9e755 . "./code.cg2js/cg-project-window.fasl")
(#x33ad5ced0805fe197c2f782fadb132b4 . "./code.cg2js/cg-property.fasl")
(#xda75d1709a08f0e96b63f786f8fd1a7f . "./code.cg2js/cg-radio-button.fasl")
(#x7a7eb79bb3824e91d41d5706a687e115 . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#x56cf03fe508992a9b877478047825c2f . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x334ec5d4c6f994e0c5b08f183649abc2 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#xf62eb01ec60b5b82ec9c8fe0836b5978 . "./code.cg2js/cg-rich-edit.fasl")
(#xb6d0effc7855c8413e403455957fb5f8 . "./code.cg2js/cg-sample-file-menu.fasl")
(#x06cdcdac8fe15e322e186671dbbf0b14 . "./code.cg2js/cg-scaling-stream.fasl")
(#x741e585d86df1fd76c94a1de7c440a0b . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#xbd051369251628d9f7a29a5292f5f72d . "./code.cg2js/cg-scroll-bar.fasl")
(#x429c6db81bb5ee046ca7e64596e64167 . "./code.cg2js/cg-scrolling-static-text.fasl")
(#x161a0c4b18722a14df9558fb5ced53c9 . "./code.cg2js/cg-selected-object.fasl")
(#xb7325a702ed8060cdf8e5dfa0925072e . "./code.cg2js/cg-shortcut-menu.fasl")
(#x3902f2e7d74ac1de16a6ebc40e54b68d . "./code.cg2js/cg-split-bar.fasl")
(#xc38289b78babc7bb09c0b5c868ca97cb . "./code.cg2js/cg-static-text.fasl")
(#x1d9c5114cb320d967c254657c05dabc8 . "./code.cg2js/cg-status-bar.fasl")
(#x5136db366f9a675e257360c4410e7b92 . "./code.cg2js/cg-string-dialog.fasl")
(#x8a823c7feabf7cd3731154cacfcc039e . "./code.cg2js/cg-tab-control.fasl")
(#xc152c25098f3297b328e81a83ae7436f . "./code.cg2js/cg-template-string.fasl")
(#x43b795e86f07fd0a29be9bdbbc6c0b06 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#x4fcd7c350e4053beea96f7ab6202e454 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#xce51cb3c94b62535c9c430ed6249a3ed . "./code.cg2js/cg-text-edit-pane.fasl")
(#x39f9c97cd4438d11b42d29f1aeaa5a8b . "./code.cg2js/cg-text-or-combo.fasl")
(#xba7a56c7ab99dbe89021651ac78cb0a7 . "./code.cg2js/cg-text-widget.fasl")
(#xb80e3905609c3ba7b58adaa7e0f2c9fd . "./code.cg2js/cg-timer.fasl")
(#xfeb83b3548e244bf9e39815363f5ecca . "./code.cg2js/cg-toggling-widget.fasl")
(#xd85b6620083e2a2efc1c7fa459efbd5c . "./code.cg2js/cg-toolbar.fasl")
(#xc924a16bb8f0678f57fcc4dd5458ca67 . "./code.cg2js/cg-tooltip.fasl")
(#xae65a261776ec2d9fc03881562782542 . "./code.cg2js/cg-touch.fasl")
(#xb8b0ba1b2481aeb7f3ef3c11fc1f91d7 . "./code.cg2js/cg-trackbar.fasl")
(#xa2a1343f1d60057aa15946fbb8f4d497 . "./code.cg2js/cg-tray.fasl")
(#xb3d74579522351903bbe45346593c383 . "./code.cg2js/cg-up-down-control.fasl")
(#x75fb797437e8a6408776a07438f9b83e . "./code.cg2js/cg-utility-dialog.fasl")
(#x8ff26a0a0969bd9cbc57a720e58dffa5 . "./code.cg2js/cg-web-browser-dde.fasl")
(#x0042eb663ccd1ede4e186e745d88b618 . "./code.cg2js/cg-web-browser.fasl")
(#xb64c74935627c36a3afb964c32723f8d . "./code.cg2js/cg-wrap-string.fasl")
(#x1b1cee31c7ba2bd955c2d20ece729da2 . "./code.cg2js/cg-yes-no-list.fasl")
(#xa3585bf7ffed688aa74d007f086e7530 . "./code.cg2js/cg.fasl")
(#x58fe9cb55ec8fa168382f939aeab2b2c . "./code.cg2js/cg-yes-no-string.fasl")
(#x97dbf8a3669dfbc3bb5ee95a9ed06404 . "./code.idejs/ide-acache.fasl")
(#x1b442e2630484134efac577e084a730a . "./code.idejs/ide-apropos.fasl")
(#xa93ba84ebadb1af74e54f1bce46bef59 . "./code.idejs/ide-base.fasl")
(#xa5a3ab93f556e8a1d8b08fbad527e9c6 . "./code.idejs/ide-class-browser.fasl")
(#x8d805012ab87a252323d4f245373e9a9 . "./code.idejs/ide-class-grapher.fasl")
(#x7a32eda4824fb86816e1d8c69b4353f7 . "./code.idejs/ide-clipboard.fasl")
(#xbc3dfc92eb84472a1e3601091c6925a3 . "./code.idejs/ide-dev.fasl")
(#xd4dbe6d3be47787a264212cac038c4da . "./code.idejs/ide-editor.fasl")
(#x7cd9cb0d4e83ae034fb00d00858ac77e . "./code.idejs/ide-find-definitions.fasl")
(#x8dda876930efc342f5d5d58979949db7 . "./code.idejs/ide-find-in-files.fasl")
(#x34de4b2819f75c4fab0b4efb1f3a97bd . "./code.idejs/ide-form.fasl")
(#x95ca5ba5afcda069934c8419d8eb729d . "./code.idejs/ide-grapher.fasl")
(#xdab00edaa08b68f54236dd9d4dacaf34 . "./code.idejs/ide-inspector.fasl")
(#xc95c03994b92d213069aa6ed0c01caf4 . "./code.idejs/ide-intro.fasl")
(#xa26f0629ea910cc8a16a478d884e529f . "./code.idejs/ide-keyshort.fasl")
(#x6c65b396994d2f33de82b7a4e693b2f6 . "./code.idejs/ide-navigator.fasl")
(#x815ff47a392e5e8482de78e0377958c0 . "./code.idejs/ide-package-list.fasl")
(#x7fc177052b48aa18dfae44d84cf372e0 . "./code.idejs/ide-patch-dialog.fasl")
(#x2405294f260724e4ce073e28d90a9d60 . "./code.idejs/ide-process-browser.fasl")
(#x287d7d9130696d7c11fb04c73c8105c7 . "./code.idejs/ide-project.fasl")
(#x3e4e02755cf1e74d3629f3bf558b1daf . "./code.idejs/ide-trace.fasl")
(#x612aef8342ec5ef1c40f1a1db4b1c564 . "./code.idejs/ide-window-list.fasl")
(#x584fdda8d86bc762c295f07d51bd7565 . "./code.idejs/ide.fasl")
(#xde049c9404b4ba293f0cbc6a4817dc96 . "./cgjs.html")
(#x55fea08d92e113f5a8381c271febbc9e . "./ssl-not-found.html")
(#x4e1b21622d7d9cc4e6fc09c7875f8430 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (format t "Incorrect checksum on file: ~a" (cdr checksum))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js" "code.idejs"))
    (format s "
(let ((path (make-pathname
             :host \"sys\"
             :directory '(:relative \"~a\")
	     :type \"fasl\"
	     )))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows
  (let ((noninteractive (sys:getenv "ACL_NONINTERACTIVE")))
    (when (or (null noninteractive)
	      (string= "" noninteractive))
      (excl::internal-message-box msg "CG/JS Installation" :type :ok))))
